@@ -678,12 +678,16 @@ ui_set_show_bitcalculating(gboolean visible)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu), visible);
 
     if (visible) {
-        /* Translators: When the bit calculation extension is visible, by 
-         * clicking on any of these individual bits, their value can be 
-         * toggled, causing the displayed integer value to be adjusted 
-         * accordingly.
+        /* Translators: When the bit editor is visible, there will be two
+         * rows of ones and zeroes shown. When the number being displayed in
+         * in the calculator is an integer value, these ones and zeroes will
+         * be sensitive, and they will correspond to the value of each of 
+         * the bits in the displayed integer number. By clicking on any of 
+         * the labels for these ones and zeroes, their value can be toggled
+         * (a one becomes a zero and a zero becomes a one), causing the 
+         * displayed integer value to be adjusted accordingly.
          */
-        ui_set_statusbar(_("Bit calculation extension activated. Click on bit values to toggle them."), "");
+        ui_set_statusbar(_("Bit editor activated. Click on bit values to toggle them."), "");
     } else {
         ui_set_statusbar("", "");
     }
@@ -775,6 +779,7 @@ ui_set_mode(enum mode_type mode)
 
         /* Reset display */
         do_clear();
+        ui_set_statusbar("", "");
     }
     
     /* Save mode */
@@ -830,10 +835,10 @@ ui_set_mode(enum mode_type mode)
 
     /* Set the title */
     if((hostname = make_hostname())) {
-        SNPRINTF(title, MAXLINE, hostname_titles[mode], hostname);
+        SNPRINTF(title, MAXLINE, gettext(hostname_titles[mode]), hostname);
         g_free(hostname);
     } else {
-        SNPRINTF(title, MAXLINE, titles[mode]);
+        SNPRINTF(title, MAXLINE, gettext(titles[mode]));
     }
     gtk_window_set_title(GTK_WINDOW(X->kframe), title);
 
@@ -2525,7 +2530,7 @@ create_kframe()
                                         GTK_BUTTONS_NONE,
                                         N_("Error loading user interface"));
         gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-                                                 N_("The user interace file %s is missing or unable to be loaded. Please check your installation."), UI_FILE);
+                                                 N_("The user interface file %s is missing or unable to be loaded. Please check your installation."), UI_FILE);
         gtk_dialog_add_buttons(GTK_DIALOG(dialog), GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT, NULL);
         
         gtk_dialog_run(GTK_DIALOG(dialog));
